import './assets/main.css';

import 'virtual:uno.css';

import { createHead } from '@unhead/vue';
import piniaPluginPersistedstate from 'pinia-plugin-persistedstate';
import { setupEruda } from './plugins/eruda';
import { setupPrimeVue } from './plugins/primevue';
import { setupRouter } from './plugins/router';
import { setupVueI18n } from './plugins/vue-i18n';

import App from './App.vue';

async function init() {
  if ((import.meta.env.MODE === 'development' || 1 === 1) && 0) {
    await setupEruda();
  }

  const app = createApp(App) //
    .use(createHead())
    .use(createPinia().use(piniaPluginPersistedstate));

  app.config.errorHandler = (error, instance, info) => {
    console.error('Global error:', error);
    console.error('Component:', instance);
    console.error('Error Info:', info);
    // 这里你可以：
    // 1. 发送错误到日志服务
    // 2. 显示全局错误提示
    // 3. 进行错误分析和处理
  };

  setupVueI18n(app);
  setupPrimeVue(app);
  setupRouter(app);

  app.config.globalProperties.$__DEV__ = $__DEV__;

  app.mount('#app');
}

init();
